@@ -12,28 +12,35 @@ from .collection import (
     Indexer,
     PartitionCallable,
     PartitionFilter,
+    UpdateCallable,
+)
+from .convenience import (
     create_collection,
+    create_view,
     open_collection,
+    open_view,
 )
 from .dataset import Attribute, Dataset, Variable
 from .version import __version__
-from .view import View, create_view, open_view
+from .view import View, ViewReference
 
 __all__ = [
-    "__version__",
-    "Attribute",
-    "Collection",
-    "create_collection",
-    "create_view",
-    "Dataset",
-    "Indexer",
-    "merging",
-    "open_collection",
-    "open_view",
-    "PartitionCallable",
-    "PartitionFilter",
-    "partitioning",
-    "Variable",
-    "version",
-    "View",
+    '__version__',
+    'Attribute',
+    'Collection',
+    'create_collection',
+    'create_view',
+    'Dataset',
+    'Indexer',
+    'merging',
+    'open_collection',
+    'open_view',
+    'PartitionCallable',
+    'PartitionFilter',
+    'partitioning',
+    'UpdateCallable',
+    'Variable',
+    'version',
+    'View',
+    'ViewReference',
 ]
